==> empathy-0.21.90.tar.gz: empathy-0.21.90/libempathy-gtk/empathy-images.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 2007 Collabora Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 * Authors: Xavier Claessens <xclaesse@gmail.com>
 */

#ifndef __EMPATHY_IMAGES_H__
#define __EMPATHY_IMAGES_H__

G_BEGIN_DECLS

#define EMPATHY_IMAGE_OFFLINE             "empathy-offline"
#define EMPATHY_IMAGE_HIDDEN              "empathy-offline"
#define EMPATHY_IMAGE_AVAILABLE           "empathy-available"
#define EMPATHY_IMAGE_BUSY                "empathy-busy"
#define EMPATHY_IMAGE_AWAY                "empathy-away"
#define EMPATHY_IMAGE_EXT_AWAY            "empathy-extended-away"
#define EMPATHY_IMAGE_UNKNOWN             "empathy-pending"

#define EMPATHY_IMAGE_MESSAGE             "im-message"
#define EMPATHY_IMAGE_NEW_MESSAGE         "im-message-new"
#define EMPATHY_IMAGE_TYPING              "user-typing"
#define EMPATHY_IMAGE_CONTACT_INFORMATION "gtk-info"
#define EMPATHY_IMAGE_GROUP_MESSAGE       "system-users"
#define EMPATHY_IMAGE_VOIP                "gnome-stock-mic"
#define EMPATHY_IMAGE_LOG                 "document-open-recent"

G_END_DECLS

#endif /* __EMPATHY_IMAGES_ICONS_H__ */

==> empathy_2.26.2.orig.tar.gz: empathy-2.26.2/libempathy-gtk/empathy-images.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 2007-2008 Collabora Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 * Authors: Xavier Claessens <xclaesse@gmail.com>
 */

#ifndef __EMPATHY_IMAGES_H__
#define __EMPATHY_IMAGES_H__

G_BEGIN_DECLS

#define EMPATHY_IMAGE_OFFLINE             "empathy-offline"
#define EMPATHY_IMAGE_HIDDEN              "empathy-offline"
#define EMPATHY_IMAGE_AVAILABLE           "empathy-available"
#define EMPATHY_IMAGE_BUSY                "empathy-busy"
#define EMPATHY_IMAGE_AWAY                "empathy-away"
#define EMPATHY_IMAGE_EXT_AWAY            "empathy-extended-away"
#define EMPATHY_IMAGE_UNKNOWN             "empathy-pending"

#define EMPATHY_IMAGE_MESSAGE             "im-message"
#define EMPATHY_IMAGE_NEW_MESSAGE         "im-message-new"
#define EMPATHY_IMAGE_TYPING              "user-typing"
#define EMPATHY_IMAGE_CONTACT_INFORMATION "gtk-info"
#define EMPATHY_IMAGE_GROUP_MESSAGE       "system-users"
#define EMPATHY_IMAGE_VOIP                "audio-input-microphone"
#define EMPATHY_IMAGE_LOG                 "document-open-recent"
#define EMPATHY_IMAGE_DOCUMENT_SEND       "document-send"

G_END_DECLS

#endif /* __EMPATHY_IMAGES_ICONS_H__ */
